@@ -21,12 +21,12 @@
    USA.
 */
 
+#include <QAction>
 #include <QBoxLayout>
 #include <QDockWidget>
 
 #include <KActionCollection>
 
-
 #include <KXmlGuiWindow>
 #include <QApplication>
 #include <KAboutData>
@@ -63,6 +63,7 @@ int main(int argc, char **argv)
     components->setModel(Presentation::ApplicationModel::Ptr::create());
 
     auto layout = new QVBoxLayout;
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(components->pageView());
     widget->setLayout(layout);
 
@@ -93,6 +94,10 @@ int main(int argc, char **argv)
     auto ac = window->actionCollection();
     ac->addAction(KStandardAction::Quit, window, SLOT(close()));
     for (auto it = actions.constBegin(); it != actions.constEnd(); ++it) {
+        auto shortcut = it.value()->shortcut();
+        if (!shortcut.isEmpty()) {
+            ac->setDefaultShortcut(it.value(), shortcut);
+        }
         ac->addAction(it.key(), it.value());
     }
 
