@@ -21,7 +21,11 @@
    USA.
 */
 
-#include <QtTest>
+#include <testlib/qtest_zanshin.h>
+
+#include <memory>
+
+#include <QMimeData>
 
 #include "utils/mockobject.h"
 
@@ -57,14 +61,14 @@ private slots:
 
         // One note and one task
         auto rootTask = Domain::Task::Ptr::create();
-        rootTask->setTitle("rootTask");
+        rootTask->setTitle(QStringLiteral("rootTask"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(rootTask);
 
         // One task under the root task
         auto childTask = Domain::Task::Ptr::create();
-        childTask->setTitle("childTask");
+        childTask->setTitle(QStringLiteral("childTask"));
         childTask->setDone(true);
         auto taskProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto taskResult = Domain::QueryResult<Domain::Task::Ptr>::create(taskProvider);
@@ -135,27 +139,27 @@ private slots:
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::update).when(rootTask).exactly(2));
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::update).when(childTask).exactly(2));
 
-        QCOMPARE(rootTask->title(), QString("newRootTask"));
-        QCOMPARE(childTask->title(), QString("newChildTask"));
+        QCOMPARE(rootTask->title(), QStringLiteral("newRootTask"));
+        QCOMPARE(childTask->title(), QStringLiteral("newChildTask"));
 
         QCOMPARE(rootTask->isDone(), true);
         QCOMPARE(childTask->isDone(), false);
 
         // WHEN
-        QMimeData *data = model->mimeData(QModelIndexList() << childTaskIndex);
+        auto data = std::unique_ptr<QMimeData>(model->mimeData(QModelIndexList() << childTaskIndex));
 
         // THEN
-        QVERIFY(data->hasFormat("application/x-zanshin-object"));
+        QVERIFY(data->hasFormat(QStringLiteral("application/x-zanshin-object")));
         QCOMPARE(data->property("objects").value<Domain::Artifact::List>(),
                  Domain::Artifact::List() << childTask);
 
         // WHEN
         auto childTask2 = Domain::Task::Ptr::create();
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask2).thenReturn(new FakeJob(this));
-        data = new QMimeData;
-        data->setData("application/x-zanshin-object", "object");
+        data.reset(new QMimeData);
+        data->setData(QStringLiteral("application/x-zanshin-object"), "object");
         data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask2));
-        model->dropMimeData(data, Qt::MoveAction, -1, -1, rootTaskIndex);
+        model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask2).exactly(1));
@@ -166,10 +170,10 @@ private slots:
         auto childTask4 = Domain::Task::Ptr::create();
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask3).thenReturn(new FakeJob(this));
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask4).thenReturn(new FakeJob(this));
-        data = new QMimeData;
-        data->setData("application/x-zanshin-object", "object");
+        data.reset(new QMimeData);
+        data->setData(QStringLiteral("application/x-zanshin-object"), "object");
         data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask3 << childTask4));
-        model->dropMimeData(data, Qt::MoveAction, -1, -1, rootTaskIndex);
+        model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask3).exactly(1));
@@ -201,7 +205,7 @@ private slots:
                                             taskRepositoryMock.getInstance());
 
         // WHEN
-        auto title = QString("New task");
+        auto title = QStringLiteral("New task");
         auto task = page.addItem(title).objectCast<Domain::Task>();
 
         // THEN
@@ -248,7 +252,7 @@ private slots:
                                             taskRepositoryMock.getInstance());
 
         // WHEN
-        const auto title = QString("New task");
+        const auto title = QStringLiteral("New task");
         const auto parentIndex = page.centralListModel()->index(0, 0);
         const auto createdTask = page.addItem(title, parentIndex).objectCast<Domain::Task>();
 
@@ -266,7 +270,7 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project1");
+        project->setName(QStringLiteral("Project1"));
 
         // ... in fact we won't list any model
         Utils::MockObject<Domain::ProjectQueries> projectQueriesMock;
@@ -276,7 +280,7 @@ private slots:
         // We'll gladly create a task though
         Utils::MockObject<Domain::TaskRepository> taskRepositoryMock;
         auto job = new FakeJob(this);
-        job->setExpectedError(KJob::KilledJobError, "Foo");
+        job->setExpectedError(KJob::KilledJobError, QStringLiteral("Foo"));
         taskRepositoryMock(&Domain::TaskRepository::createInProject).when(any<Domain::Task::Ptr>(),
                                                                           any<Domain::Project::Ptr>())
                                                                     .thenReturn(job);
@@ -290,11 +294,11 @@ private slots:
         page.setErrorHandler(&errorHandler);
 
         // WHEN
-        page.addItem("New task");
+        page.addItem(QStringLiteral("New task"));
 
         // THEN
         QTest::qWait(150);
-        QCOMPARE(errorHandler.m_message, QString("Cannot add task New task in project Project1: Foo"));
+        QCOMPARE(errorHandler.m_message, QStringLiteral("Cannot add task New task in project Project1: Foo"));
     }
 
     void shouldDeleteItems()
@@ -344,12 +348,12 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project1");
+        project->setName(QStringLiteral("Project1"));
 
         // Two tasks
         auto task1 = Domain::Task::Ptr::create();
         auto task2 = Domain::Task::Ptr::create();
-        task2->setTitle("Task2");
+        task2->setTitle(QStringLiteral("Task2"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(task1);
@@ -366,7 +370,7 @@ private slots:
 
         Utils::MockObject<Domain::TaskRepository> taskRepositoryMock;
         auto job = new FakeJob(this);
-        job->setExpectedError(KJob::KilledJobError, "Foo");
+        job->setExpectedError(KJob::KilledJobError, QStringLiteral("Foo"));
         taskRepositoryMock(&Domain::TaskRepository::remove).when(task2).thenReturn(job);
 
         Presentation::ProjectPageModel page(project,
@@ -383,7 +387,7 @@ private slots:
 
         // THEN
         QTest::qWait(150);
-        QCOMPARE(errorHandler.m_message, QString("Cannot remove task Task2 from project Project1: Foo"));
+        QCOMPARE(errorHandler.m_message, QStringLiteral("Cannot remove task Task2 from project Project1: Foo"));
     }
 
     void shouldPromoteItem()
@@ -433,12 +437,12 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project1");
+        project->setName(QStringLiteral("Project1"));
 
         // Two tasks
         auto task1 = Domain::Task::Ptr::create();
         auto task2 = Domain::Task::Ptr::create();
-        task2->setTitle("Task2");
+        task2->setTitle(QStringLiteral("Task2"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(task1);
@@ -455,7 +459,7 @@ private slots:
 
         Utils::MockObject<Domain::TaskRepository> taskRepositoryMock;
         auto job = new FakeJob(this);
-        job->setExpectedError(KJob::KilledJobError, "Foo");
+        job->setExpectedError(KJob::KilledJobError, QStringLiteral("Foo"));
         taskRepositoryMock(&Domain::TaskRepository::promoteToProject).when(task2).thenReturn(job);
 
         Presentation::ProjectPageModel page(project,
@@ -472,7 +476,7 @@ private slots:
 
         // THEN
         QTest::qWait(150);
-        QCOMPARE(errorHandler.m_message, QString("Cannot promote task Task2 to be a project: Foo"));
+        QCOMPARE(errorHandler.m_message, QStringLiteral("Cannot promote task Task2 to be a project: Foo"));
     }
 
     void shouldGetAnErrorMessageWhenUpdateTaskFailed()
@@ -481,11 +485,11 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project1");
+        project->setName(QStringLiteral("Project1"));
 
         // One note and one task
         auto rootTask = Domain::Task::Ptr::create();
-        rootTask->setTitle("rootTask");
+        rootTask->setTitle(QStringLiteral("rootTask"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(rootTask);
@@ -513,14 +517,14 @@ private slots:
 
         // WHEN
         auto job = new FakeJob(this);
-        job->setExpectedError(KJob::KilledJobError, "Foo");
+        job->setExpectedError(KJob::KilledJobError, QStringLiteral("Foo"));
         taskRepositoryMock(&Domain::TaskRepository::update).when(rootTask).thenReturn(job);
 
         QVERIFY(model->setData(rootTaskIndex, "newRootTask"));
 
         // THEN
         QTest::qWait(150);
-        QCOMPARE(errorHandler.m_message, QString("Cannot modify task rootTask in project Project1: Foo"));
+        QCOMPARE(errorHandler.m_message, QStringLiteral("Cannot modify task rootTask in project Project1: Foo"));
     }
 
     void shouldGetAnErrorMessageWhenAssociateTaskFailed()
@@ -529,11 +533,11 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project1");
+        project->setName(QStringLiteral("Project1"));
 
         // One note and one task
         auto rootTask = Domain::Task::Ptr::create();
-        rootTask->setTitle("rootTask");
+        rootTask->setTitle(QStringLiteral("rootTask"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(rootTask);
@@ -561,20 +565,20 @@ private slots:
 
         // WHEN
         auto childTask3 = Domain::Task::Ptr::create();
-        childTask3->setTitle("childTask3");
+        childTask3->setTitle(QStringLiteral("childTask3"));
         auto childTask4 = Domain::Task::Ptr::create();
         auto job = new FakeJob(this);
-        job->setExpectedError(KJob::KilledJobError, "Foo");
+        job->setExpectedError(KJob::KilledJobError, QStringLiteral("Foo"));
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask3).thenReturn(job);
         taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask4).thenReturn(new FakeJob(this));
-        auto data = new QMimeData;
-        data->setData("application/x-zanshin-object", "object");
+        auto data = std::make_unique<QMimeData>();
+        data->setData(QStringLiteral("application/x-zanshin-object"), "object");
         data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask3 << childTask4));
-        model->dropMimeData(data, Qt::MoveAction, -1, -1, rootTaskIndex);
+        model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, rootTaskIndex);
 
         // THEN
         QTest::qWait(150);
-        QCOMPARE(errorHandler.m_message, QString("Cannot move task childTask3 as a sub-task of rootTask: Foo"));
+        QCOMPARE(errorHandler.m_message, QStringLiteral("Cannot move task childTask3 as a sub-task of rootTask: Foo"));
         QVERIFY(taskRepositoryMock(&Domain::TaskRepository::associate).when(rootTask, childTask4).exactly(1));
     }
 
@@ -584,21 +588,21 @@ private slots:
 
         // One project
         auto project = Domain::Project::Ptr::create();
-        project->setName("Project");
+        project->setName(QStringLiteral("Project"));
 
         // One top level task
         auto topLevelTask = Domain::Task::Ptr::create();
-        topLevelTask->setTitle("rootTask");
+        topLevelTask->setTitle(QStringLiteral("rootTask"));
         auto topLevelProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto topLevelResult = Domain::QueryResult<Domain::Task::Ptr>::create(topLevelProvider);
         topLevelProvider->append(topLevelTask);
 
         // Two tasks under the top level task
         auto childTask1 = Domain::Task::Ptr::create();
-        childTask1->setTitle("childTask1");
+        childTask1->setTitle(QStringLiteral("childTask1"));
         childTask1->setDone(true);
         auto childTask2 = Domain::Task::Ptr::create();
-        childTask2->setTitle("childTask2");
+        childTask2->setTitle(QStringLiteral("childTask2"));
         childTask2->setDone(false);
         auto taskProvider = Domain::QueryResultProvider<Domain::Task::Ptr>::Ptr::create();
         auto taskResult = Domain::QueryResult<Domain::Task::Ptr>::create(taskProvider);
@@ -629,10 +633,10 @@ private slots:
         projectRepositoryMock(&Domain::ProjectRepository::associate).when(project, childTask1).thenReturn(new FakeJob(this));
         projectRepositoryMock(&Domain::ProjectRepository::associate).when(project, childTask2).thenReturn(new FakeJob(this));
 
-        auto data = new QMimeData;
-        data->setData("application/x-zanshin-object", "object");
+        auto data = std::make_unique<QMimeData>();
+        data->setData(QStringLiteral("application/x-zanshin-object"), "object");
         data->setProperty("objects", QVariant::fromValue(Domain::Artifact::List() << childTask1 << childTask2)); // both will be DnD on the empty part
-        model->dropMimeData(data, Qt::MoveAction, -1, -1, QModelIndex());
+        model->dropMimeData(data.get(), Qt::MoveAction, -1, -1, QModelIndex());
 
         // THEN
         QTest::qWait(150);
@@ -641,6 +645,6 @@ private slots:
     }
 };
 
-QTEST_MAIN(ProjectPageModelTest)
+ZANSHIN_TEST_MAIN(ProjectPageModelTest)
 
 #include "projectpagemodeltest.moc"
